
flax.linen
==========

Linen is the Flax Module system. Read more about our design goals in the `Linen README <https://github.com/google/flax/blob/main/flax/linen/README.md>`_.

.. toctree::
  :maxdepth: 2

  module
  init_apply
  layers
  activation_functions
  initializers
  transformations
  inspection
  variable
  spmd
  decorators
  profiling